@@ -1,10 +1,18 @@
 rob.int <- function(x, rc, l.grid = 1000, tol = 1e-4, var.range = NULL){
 
+
 lo <- l.grid
 
 margin <- x$VC$margins[2]
 params <- x$coefficients
 
+
+min.dn <- 1e-160 # x$VC$min.dn
+min.pr <- x$VC$min.pr
+max.pr <- x$VC$max.pr 
+
+
+
 j <- 1; inds <- posi <- NULL 
 
 if(is.null(var.range)){
@@ -15,9 +23,8 @@ if(rlo > 1) lo <- round(lo*rlo)
 
 if( margin %in% c("N","N2","GU","rGU","LO","LN") )                            seq.y <- seq(min(x$VC$y1) - ((max(x$VC$y1) - min(x$VC$y1))/2), max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
 if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP","GPII","GPo")  )   seq.y <- seq(1e-12, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
-if( margin %in% c("TW")  )   seq.y <- seq(0, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
-
-if( margin %in% c("BE")  )                                                    seq.y <- seq(1e-12, 0.9999999,  length.out = lo)      
+if( margin %in% c("TW")  )                                                    seq.y <- seq(0, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
+if( margin %in% c("BE")  )                                                    seq.y <- seq(1e-12, 0.999999,  length.out = lo)      
 
 }else{
 
@@ -61,9 +68,11 @@ if( margin %in% c("DAGUM","SM","TW") ){
 
 for(i in 1:lo){ 
 
-  ires <- intB(seq.y[i], eta, sigma2, sigma2.st, nu, nu.st, margin, rc) 
+  ires <- intB(seq.y[i], eta, sigma2, sigma2.st, nu, nu.st, margin, rc, min.dn, min.pr, max.pr) 
+  
+  if(min(ires) == max(ires) && min(ires) < tol) inds[i] <- TRUE else inds[i] <- FALSE
+
   
-  if(min(ires) == max(ires) && min(ires) < tol) inds[i] <- TRUE else inds[i] <- FALSE 
   if(i > 1 && inds[i] != inds[i-1]) { if(j==1){ posi[j] <- i-1; j <- j + 1} else posi[2] <- i}  
 
 }
@@ -81,7 +90,7 @@ posi <- NULL; j <- 1
 
   for(i in 1:lo){ 
 
-    ires <- intB(seq.y[i], eta, sigma2, sigma2.st, nu, nu.st, margin, rc) 
+    ires <- intB(seq.y[i], eta, sigma2, sigma2.st, nu, nu.st, margin, rc, min.dn, min.pr, max.pr) 
   
     if(min(ires) == max(ires) && min(ires) < tol) inds[i] <- TRUE else inds[i] <- FALSE 
     
@@ -98,9 +107,6 @@ posi <- NULL; j <- 1
 
 
 
-
-
-
 bs <- c(seq.y[posi[1]], seq.y[posi[2]])
 names(bs) <- c("lB", "uB")
 bs
